@@ -1,4 +1,4 @@
-# Author: Paul Poncet
+# Author: P. Poncet
 
 vieu <-
 function(x,                       # sample (the data)
@@ -12,7 +12,7 @@ function(x,                       # sample (the data)
 #  of the derivative of the density 
 ###################################################
 
-  if (pmatch(tolower(kernel), "normal", no = 0)) {
+  if (pmatch(tolower(kernel), "normal", nomatch = 0)) {
     kernel <- "gaussian"
   } else kernel <- match.arg(tolower(kernel), c(.kernelList, "uniform")) # '.kernelList' is defined in 'K.R'
     
